==> 8.2.zip: 8.2/get_response_attachment_by_params.php <==
<?php
require_once('config.php');

$error_message;
$valid = true;
$json_return = array();

//$sql = "Select rowid, attachment, file_name from wko_ref where mst_rowid = ".$_REQUEST['rowid'];

$site_cd = $_REQUEST['site_cd'];
$rowid= $_REQUEST['rowid'];
$dvc_id = $_REQUEST['dvc_id'];
$MobileURL = $_REQUEST['url'];
$Folder = $_REQUEST['folder'];

$uploaddir;
$uploaddir = "C:\\wamp64\\www\\".$Folder."\\temp_".$dvc_id."\\";



if (!is_dir($uploaddir)) {
		mkdir($uploaddir, 0777, true);
		mkdir($uploaddir."\\thumbnail\\", 0777, true);
		
		
	}
	

$MobileURLFullSize = $MobileURL . "/temp_".$dvc_id."/";
$MobileURLTnSize = $MobileURL . "/temp_".$dvc_id."/thumbnail/";

$exportdir = "C:\\wamp64\\www\\". $Folder ."\\temp_".$dvc_id."\\";
$exportdirtn = "C:\\wamp64\\www\\". $Folder ."\\temp_".$dvc_id."\\thumbnail\\";

$counter =0;
$sql = "SELECT RowID, attachment, file_name  from wko_ref (NOLOCK) 
		where site_cd ='".$site_cd."' 
		and mst_RowID ='".$rowid."' 
		and column2 = 'RESPONSE_SIGN' 
		and DataLength(attachment) > 0
		and file_name not like '%xlsx%' 
		and file_name not like '%xls%'";

$stmt = sqlsrv_query($conn, $sql);
//echo  $sql;
if (!$stmt) {
     $error_message = "Error selecting table (itm_ref)";

     die(print_r(sqlsrv_errors(), true));
}

$mime = null;
$json_img_link = array();

 /* $json1 = json_encode($json_img_link);
	 echo$json1; */

do {
     while ($row = sqlsrv_fetch_array($stmt, SQLSRV_FETCH_ASSOC)) {
          $Photo = $row['attachment'];
          $fileName = $row['file_name'];
          $rowid = $row['RowID'];
		  
		 
          if (strpos($fileName, 'jpg') == true){
               $mime = 'image/jpg';
          }

          if (strpos($fileName, 'jpeg') == true){
               $mime = 'image/jpeg';
          }

          if (strpos($fileName, 'gif') == true){
               $mime = 'image/gif';
          }

          if (strpos($fileName, 'png') == true){
               $mime = 'image/png';
          }
   
          $exportFullPathFileName = $exportdir.$fileName;
          $exportFullPathTNFileName = $exportdirtn.$fileName;
		  
		 /// echo $exportdir;
           //echo $exportFullPathTNFileName;
		  
          $publicFullPathFileName = $MobileURLFullSize.$fileName;		  
          $publicFullPathTNFileName = $MobileURLTnSize.$fileName;
	      
		   $publicFullPathFileName = $MobileURLFullSize.$fileName;		  
           $publicFullPathTNFileName = $MobileURLTnSize.$fileName;	  
		   
		   //echo $publicFullPathFileName;

          //Export and create full size file
           if (file_exists($exportFullPathFileName)){
			  $counter++;
			   $newname  = str_replace(".jpg","_".$counter.".jpg",$fileName);
				//echo  $newname;
			  
			  $exportFullPathFileName = $exportdir.$newname;
			  $exportFullPathTNFileName = $exportdirtn.$newname;
			  
			  
			$publicFullPathFileName = $MobileURLFullSize.$newname;	  
			$publicFullPathTNFileName = $MobileURLTnSize.$newname;
	      
			$publicFullPathFileName = $MobileURLFullSize.$newname; 
			$publicFullPathTNFileName = $MobileURLTnSize.$newname;
			  
			  //echo $newname;
			  
		  }
		  
		  If ($file = fopen($exportFullPathFileName,"w")) {
			 if (fwrite($file, $Photo)==false) {
				 echo "Error Write Files";
			 }
			 fclose($file);
		  }
		  
		 

          //Export and create thumbnail size file
          //$file = fopen($exportFullPathTNFileName,"w");   
		  
          //$image = imagecreatefromjpeg($exportFullPathFileName);
          //imagejpeg($image, $exportFullPathTNFileName, 20);
		  
		  
		 /*  $imageObject = imagecreatefromjpeg($exportFullPathFileName);

			# Get exif information
			$exif = exif_read_data($exportFullPathFileName);
			# Add some error handling

			# Get orientation
			$orientation = $exif['Orientation'];

			# Manipulate image
			switch ($orientation) {
				case 2:
					imageflip($imageObject, IMG_FLIP_HORIZONTAL);
					break;
				case 3:
					$imageObject = imagerotate($imageObject, 180, 0);
					break;
				case 4:
					imageflip($imageObject, IMG_FLIP_VERTICAL);
					break;
				case 5:
					$imageObject = imagerotate($imageObject, -90, 0);
					imageflip($imageObject, IMG_FLIP_HORIZONTAL);
					break;
				case 6:
					$imageObject = imagerotate($imageObject, -90, 0);
					break;
				case 7:
					$imageObject = imagerotate($imageObject, 90, 0);
					imageflip($imageObject, IMG_FLIP_HORIZONTAL);
					break;
				case 8:
					$imageObject = imagerotate($imageObject, 90, 0); 
					break;
			}

			# Write image
			imagejpeg($imageObject, $exportFullPathTNFileName, 20); */
		  
          //fclose($file);

         // echo $publicFullPathFileName;
          $json_img_link['rowid'] = $rowid;
          $json_img_link['type'] = 'image';
		  $json_img_link['file_name'] = $fileName;
          $json_img_link['thumbnail_link'] = $publicFullPathTNFileName;
          $json_img_link['full_size_link'] = $publicFullPathFileName;
          $json_img_link['file_source'] = 'server';
          array_push($json_return, $json_img_link);

     }
} while (sqlsrv_next_result($stmt));

echo returnData($json_return);

function returnData($json){
	$returnData = array(
	'status' => 'SUCCESS',
	'message' => 'Work Order Attachment Retrieve Successfully',
	'data' => $json);
	
	echo json_encode($returnData);
}


function returnError($error_message){
	$json = array();
	
	$returnData = array(
	'status' => 'ERROR',
	'message' => $error_message,
	'data' => $json);
	
	echo json_encode($returnData);
	
	sqlsrv_free_stmt( $stmt);
	sqlsrv_close( $conn);	
		
	exit();
}

// $b64Src = "data:" . $mime . ";base64," . base64_encode($Photo);
// echo '<img src="' . $b64Src . '" alt="" />';

sqlsrv_free_stmt($stmt);
sqlsrv_close($conn);

==> 8.8.zip: 8.8/get_response_attachment_by_params.php <==
<?php
require_once('config.php');

$error_message;
$valid = true;
$json_return = array();

//$sql = "Select rowid, attachment, file_name from wko_ref where mst_rowid = ".$_REQUEST['rowid'];

$site_cd = $_REQUEST['site_cd'];
$rowid= $_REQUEST['rowid'];
$dvc_id = $_REQUEST['dvc_id'];
$MobileURL = $_REQUEST['url'];
$Folder = $_REQUEST['folder'];

$uploaddir;
$uploaddir = "C:\\wamp64\\www\\".$Folder."\\temp_".$dvc_id."\\";



if (!is_dir($uploaddir)) {
		mkdir($uploaddir, 0777, true);
		mkdir($uploaddir."\\thumbnail\\", 0777, true);
		
		
	}
	

$MobileURLFullSize = $MobileURL . "/temp_".$dvc_id."/";
$MobileURLTnSize = $MobileURL . "/temp_".$dvc_id."/thumbnail/";

$exportdir = "C:\\wamp64\\www\\". $Folder ."\\temp_".$dvc_id."\\";
$exportdirtn = "C:\\wamp64\\www\\". $Folder ."\\temp_".$dvc_id."\\thumbnail\\";

$counter =0;
$sql = "SELECT RowID, attachment, file_name  from wko_ref (NOLOCK) 
		where site_cd ='".$site_cd."' 
		And mst_RowID ='".$rowid."' 
		And column2 = 'RESPONSE_SIGN' 
		And DataLength(attachment) > 0 
		And	DataLength(attachment) is not null
		And mst_RowID is not null
		And file_name not like '%xlsx%' 
		And file_name not like '%xls%'";

$stmt = sqlsrv_query($conn, $sql);
//echo  $sql;
if (!$stmt) {
     $error_message = "Error selecting table (itm_ref)";

     die(print_r(sqlsrv_errors(), true));
}

$mime = null;
$json_img_link = array();

 /* $json1 = json_encode($json_img_link);
	 echo$json1; */

do {
     while ($row = sqlsrv_fetch_array($stmt, SQLSRV_FETCH_ASSOC)) {
          $Photo = $row['attachment'];
          $fileName = $row['file_name'];
          $rowid = $row['RowID'];
		  

          $exportFullPathFileName = $exportdir.$fileName;
          $exportFullPathTNFileName = $exportdirtn.$fileName;
		  
          $publicFullPathFileName = $MobileURLFullSize.$fileName;		  
          $publicFullPathTNFileName = $MobileURLTnSize.$fileName;
	        
		
           if (file_exists($exportFullPathFileName)){
			$counter++;
			$newname  = str_replace(".jpg","_".$counter.".jpg",$fileName);
				
			$exportFullPathFileName = $exportdir.$newname;
			$exportFullPathTNFileName = $exportdirtn.$newname;
			  
			$publicFullPathFileName = $MobileURLFullSize.$newname;	  
			$publicFullPathTNFileName = $MobileURLTnSize.$newname;
			  
			  
		  }
		  
		  If ($file = fopen($exportFullPathFileName,"w")) {
			 if (fwrite($file, $Photo)==false) {
				 echo "Error Write Files";
			 }
			 fclose($file);
		  }
		  
          $json_img_link['rowid'] = $rowid;
          $json_img_link['type'] = 'image';
		  $json_img_link['file_name'] = $fileName;
          $json_img_link['thumbnail_link'] = $publicFullPathTNFileName;
          $json_img_link['full_size_link'] = $publicFullPathFileName;
          $json_img_link['file_source'] = 'server';
          array_push($json_return, $json_img_link);

     }
} while (sqlsrv_next_result($stmt));

if( $stmt ) {
	 sqlsrv_commit( $conn );
	 sqlsrv_close( $conn);	
	 returnData($json_return);	
} else {
	 sqlsrv_rollback( $conn );
	 $error_message = "Transaction rolled back.<br />";
	 returnError($error_message);
}

function returnData($json){
	$returnData = array(
	'status' => 'SUCCESS',
	'message' => 'Work Request Attachment Retrieve Successfully',
	'data' => $json);
	
	echo json_encode($returnData);
}

function returnError($error_message){
	$json = array();
	
	$returnData = array(
	'status' => 'ERROR',
	'message' => $error_message,
	'data' => $json);
	
	echo json_encode($returnData);
	exit();
}

?>
